pub struct Detector<'a> { /* private fields */ }Expand description
Encapsulates logic that can detect an Aztec Code in an image, even if the Aztec Code is rotated or skewed, or partially obscured.
@author David Olivier @author Frank Yellin
Implementations
Sourceimpl<'a> Detector<'_>
impl<'a> Detector<'_>
pub fn new(image: &'a BitMatrix) -> Detector<'a>
pub fn detect_false(&mut self) -> Result<AztecDetectorRXingResult>
Sourcepub fn detect(&mut self, is_mirror: bool) -> Result<AztecDetectorRXingResult>
pub fn detect(&mut self, is_mirror: bool) -> Result<AztecDetectorRXingResult>
Detects an Aztec Code in an image.
@param isMirror if true, image is a mirror-image of original @return {@link AztecDetectorRXingResult} encapsulating results of detecting an Aztec Code @throws NotFoundException if no Aztec Code can be found