pub struct BitSource { /* private fields */ }Expand description
This provides an easy abstraction to read bits at a time from a sequence of bytes, where the number of bits read is not often a multiple of 8.
This class is thread-safe but not reentrant -- unless the caller modifies the bytes array it passed in, in which case all bets are off.
@author Sean Owen
Implementations
sourceimpl BitSource
impl BitSource
sourcepub fn new(bytes: Vec<u8>) -> Self
pub fn new(bytes: Vec<u8>) -> Self
@param bytes bytes from which this will read bits. Bits will be read from the first byte first. Bits are read within a byte from most-significant to least-significant bit.
sourcepub fn getBitOffset(&self) -> usize
pub fn getBitOffset(&self) -> usize
@return index of next bit in current byte which would be read by the next call to {@link #readBits(int)}.
sourcepub fn getByteOffset(&self) -> usize
pub fn getByteOffset(&self) -> usize
@return index of next byte in input byte array which would be read by the next call to {@link #readBits(int)}.
sourcepub fn readBits(&mut self, numBits: usize) -> Result<u32>
pub fn readBits(&mut self, numBits: usize) -> Result<u32>
@param numBits number of bits to read @return int representing the bits read. The bits will appear as the least-significant bits of the int @throws IllegalArgumentException if numBits isn’t in [1,32] or more than is available
pub fn peak_bits(&self, numBits: usize) -> Result<u32>