pub struct DecoderRXingResult { /* private fields */ }
Encapsulates the result of decoding a matrix of bits. This typically applies to 2D barcode formats. For now it contains the raw bytes obtained, as well as a String interpretation of those bytes, if applicable.

@author Sean Owen

Implementations

source

impl DecoderRXingResult

source

pub fn new( rawBytes: Vec<u8>, text: String, byteSegments: Vec<Vec<u8>>, ecLevel: String ) -> Self

source

pub fn with_symbology( rawBytes: Vec<u8>, text: String, byteSegments: Vec<Vec<u8>>, ecLevel: String, symbologyModifier: u32 ) -> Self

source

pub fn with_sa( rawBytes: Vec<u8>, text: String, byteSegments: Vec<Vec<u8>>, ecLevel: String, saSequence: i32, saParity: i32 ) -> Self

source

pub fn with_all( rawBytes: Vec<u8>, text: String, byteSegments: Vec<Vec<u8>>, ecLevel: String, saSequence: i32, saParity: i32, symbologyModifier: u32, contentType: String, isMirrored: bool ) -> Self

source

pub fn getRawBytes(&self) -> &Vec<u8>

@return raw bytes representing the result, or {@code null} if not applicable

source

pub fn getNumBits(&self) -> usize

@return how many bits of {@link #getRawBytes()} are valid; typically 8 times its length @since 3.3.0

source

pub fn setNumBits(&mut self, numBits: usize)

@param numBits overrides the number of bits that are valid in {@link #getRawBytes()} @since 3.3.0

source

pub fn getText(&self) -> &str

@return text representation of the result

source

pub fn getByteSegments(&self) -> &Vec<Vec<u8>>

@return list of byte segments in the result, or {@code null} if not applicable

source

pub fn getECLevel(&self) -> &str

@return name of error correction level used, or {@code null} if not applicable

source

pub fn getErrorsCorrected(&self) -> usize

@return number of errors corrected, or {@code null} if not applicable

source

pub fn setErrorsCorrected(&mut self, errorsCorrected: usize)

source

pub fn getErasures(&self) -> usize

@return number of erasures corrected, or {@code null} if not applicable

source

pub fn setErasures(&mut self, erasures: usize)

source

pub fn getOther(&self) -> Option<Rc<dyn Any>>

@return arbitrary additional metadata

source

pub fn setOther(&mut self, other: Option<Rc<dyn Any>>)

source

pub fn hasStructuredAppend(&self) -> bool

source

pub fn getStructuredAppendParity(&self) -> i32

source

pub fn getStructuredAppendSequenceNumber(&self) -> i32

source

pub fn getSymbologyModifier(&self) -> u32

source

pub fn getContentType(&self) -> &str

source

pub fn setContentType(&mut self, content_type: String)

source

pub fn getIsMirrored(&self) -> bool

source

pub fn setIsMirrored(&mut self, is_mirrored: bool)