Struct rxing::common::ECIEncoderSet

source ·
pub struct ECIEncoderSet { /* private fields */ }
Set of CharsetEncoders for a given input string

Invariants:

  • The list contains only encoders from CharacterSetECI (list is shorter then the list of encoders available on the platform for which ECI values are defined).
  • The list contains encoders at least one encoder for every character in the input.
  • The first encoder in the list is always the ISO-8859-1 encoder even of no character in the input can be encoded by it.
  • If the input contains a character that is not in ISO-8859-1 then the last two entries in the list will be the UTF-8 encoder and the UTF-16BE encoder.

@author Alex Geller

Implementations

source

impl ECIEncoderSet

source

pub fn new( stringToEncodeMain: &str, priorityCharset: Option<CharacterSet>, fnc1: Option<&str> ) -> Self

Constructs an encoder set

@param stringToEncode the string that needs to be encoded @param priorityCharset The preferred {@link Charset} or null. @param fnc1 fnc1 denotes the character in the input that represents the FNC1 character or -1 for a non-GS1 bar code. When specified, it is considered an error to pass it as argument to the methods canEncode() or encode().

source

pub fn len(&self) -> usize

source

pub fn is_empty(&self) -> bool

source

pub fn getCharsetName(&self, index: usize) -> Option<&'static str>

source

pub fn getCharset(&self, index: usize) -> Option<CharacterSet>

source

pub fn get_eci(&self, encoderIndex: usize) -> Eci

source

pub fn getPriorityEncoderIndex(&self) -> Option<usize>

source

pub fn canEncode(&self, c: &str, encoderIndex: usize) -> Option<bool>

source

pub fn encode_char(&self, c: &str, encoderIndex: usize) -> Option<Vec<u8>>

source

pub fn encode_string(&self, s: &str, encoderIndex: usize) -> Option<Vec<u8>>