Struct rxing::common::StringUtils
source · pub struct StringUtils {}Expand description
Common string-related functions.
@author Sean Owen @author Alex Dupre
Implementations
sourceimpl StringUtils
impl StringUtils
sourcepub fn guessEncoding(
bytes: &[u8],
hints: &DecodingHintDictionary
) -> Option<&'static str>
pub fn guessEncoding( bytes: &[u8], hints: &DecodingHintDictionary ) -> Option<&'static str>
@param bytes bytes encoding a string, whose encoding should be guessed @param hints decode hints if applicable @return name of guessed encoding; at the moment will only guess one of: “SJIS”, “UTF8”, “ISO8859_1”, or the platform default encoding if none of these can possibly be correct
sourcepub fn guessCharset(
bytes: &[u8],
hints: &DecodingHintDictionary
) -> Option<CharacterSet>
pub fn guessCharset( bytes: &[u8], hints: &DecodingHintDictionary ) -> Option<CharacterSet>
@param bytes bytes encoding a string, whose encoding should be guessed @param hints decode hints if applicable @return Charset of guessed encoding; at the moment will only guess one of: {@link #SHIFT_JIS_CHARSET}, {@link StandardCharsets#UTF_8}, {@link StandardCharsets#ISO_8859_1}, {@link StandardCharsets#UTF_16}, or the platform default encoding if none of these can possibly be correct