GridSampler

Trait GridSampler 

pub trait GridSampler {
    // Provided methods
    fn sample_grid_detailed(
        &self,
        image: &BitMatrix,
        dimensionX: u32,
        dimensionY: u32,
        dst: Quadrilateral,
        src: Quadrilateral,
    ) -> Result<(BitMatrix, [Point; 4])> { ... }
    fn sample_grid(
        &self,
        image: &BitMatrix,
        dimensionX: u32,
        dimensionY: u32,
        controls: &[SamplerControl],
    ) -> Result<(BitMatrix, [Point; 4])> { ... }
    fn checkAndNudgePoints(
        &self,
        image: &BitMatrix,
        points: &mut [Point],
    ) -> Result<()> { ... }
}
Implementations of this class can, given locations of finder patterns for a QR code in an image, sample the right points in the image to reconstruct the QR code, accounting for perspective distortion. It is abstracted since it is relatively expensive and should be allowed to take advantage of platform-specific optimized implementations, like Sun’s Java Advanced Imaging library, but which may not be available in other environments such as J2ME, and vice versa.

The implementation used can be controlled by calling {@link #setGridSampler(GridSampler)} with an instance of a class which implements this interface.

@author Sean Owen

Provided Methods

fn sample_grid_detailed( &self, image: &BitMatrix, dimensionX: u32, dimensionY: u32, dst: Quadrilateral, src: Quadrilateral, ) -> Result<(BitMatrix, [Point; 4])>

Samples an image for a rectangular matrix of bits of the given dimension. The sampling transformation is determined by the coordinates of 4 points, in the original and transformed image space.

@param image image to sample @param dimensionX width of {@link BitMatrix} to sample from image @param dimensionY height of {@link BitMatrix} to sample from image @param p1ToX point 1 preimage X @param p1ToY point 1 preimage Y @param p2ToX point 2 preimage X @param p2ToY point 2 preimage Y @param p3ToX point 3 preimage X @param p3ToY point 3 preimage Y @param p4ToX point 4 preimage X @param p4ToY point 4 preimage Y @param p1FromX point 1 image X @param p1FromY point 1 image Y @param p2FromX point 2 image X @param p2FromY point 2 image Y @param p3FromX point 3 image X @param p3FromY point 3 image Y @param p4FromX point 4 image X @param p4FromY point 4 image Y @return {@link BitMatrix} representing a grid of points sampled from the image within a region defined by the “from” parameters @throws NotFoundException if image can’t be sampled, for example, if the transformation defined by the given points is invalid or results in sampling outside the image boundaries

fn sample_grid( &self, image: &BitMatrix, dimensionX: u32, dimensionY: u32, controls: &[SamplerControl], ) -> Result<(BitMatrix, [Point; 4])>

fn checkAndNudgePoints( &self, image: &BitMatrix, points: &mut [Point], ) -> Result<()>

Checks a set of points that have been transformed to sample points on an image against the image's dimensions to see if the point are even within the image.

This method will actually "nudge" the endpoints back onto the image if they are found to be barely (less than 1 pixel) off the image. This accounts for imperfect detection of finder patterns in an image where the QR Code runs all the way to the image border.

For efficiency, the method will check points from either end of the line until one is found to be within the image. Because the set of points are assumed to be linear, this is valid.

@param image image into which the points should map @param points actual points in x1,y1,…,xn,yn form @throws NotFoundException if an endpoint is lies outside the image boundaries

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors