Module rxing::datamatrix::decoder

source ·

Modules

Structs

  • @author bbrown@google.com (Brian Brown)
  • Encapsulates a block of data within a Data Matrix Code. Data Matrix Codes may split their data into

  • The main class which implements Data Matrix Code decoding -- as opposed to locating and extracting

  • Encapsulates the parameters for one error-correction block in one symbol version.

  • Encapsulates a set of error-correction blocks in one symbol version. Most versions will

  • The Version object encapsulates attributes about a particular size Data Matrix Code.

Type Aliases