Struct rxing::datamatrix::decoder::DataBlock
source · pub struct DataBlock { /* private fields */ }Expand description
Encapsulates a block of data within a Data Matrix Code. Data Matrix Codes may split their data into multiple blocks, each of which is a unit of data and error-correction codewords. Each is represented by an instance of this class.
@author bbrown@google.com (Brian Brown)
Implementations
sourceimpl DataBlock
impl DataBlock
pub fn new(numDataCodewords: u32, codewords: Vec<u8>) -> Self
sourcepub fn getDataBlocks(
rawCodewords: &[u8],
version: &Version,
fix259: bool
) -> Result<Vec<DataBlock>>
pub fn getDataBlocks( rawCodewords: &[u8], version: &Version, fix259: bool ) -> Result<Vec<DataBlock>>
When Data Matrix Codes use multiple data blocks, they actually interleave the bytes of each of them. That is, the first byte of data block 1 to n is written, then the second bytes, and so on. This method will separate the data into original blocks.
@param rawCodewords bytes as read directly from the Data Matrix Code @param version version of the Data Matrix Code @return DataBlocks containing original bytes, “de-interleaved” from representation in the Data Matrix Code
pub fn getNumDataCodewords(&self) -> u32
pub fn getCodewords(&self) -> &[u8] ⓘ