pub struct Decoder(/* private fields */);Expand description
The main class which implements Data Matrix Code decoding -- as opposed to locating and extracting the Data Matrix Code from an image.
@author bbrown@google.com (Brian Brown)
Implementations
Sourceimpl Decoder
impl Decoder
pub fn new() -> Self
Sourcepub fn decode(&self, bits: &BitMatrix) -> Result<DecoderRXingResult>
pub fn decode(&self, bits: &BitMatrix) -> Result<DecoderRXingResult>
Decodes a Data Matrix Code represented as a {@link BitMatrix}. A 1 or "true" is taken to mean a black module.
@param bits booleans representing white/black Data Matrix Code modules @return text and bytes encoded within the Data Matrix Code @throws FormatException if the Data Matrix Code cannot be decoded @throws ChecksumException if error correction fails
Sourcepub fn decode_bools(&self, image: &[Vec<bool>]) -> Result<DecoderRXingResult>
pub fn decode_bools(&self, image: &[Vec<bool>]) -> Result<DecoderRXingResult>
Convenience method that can decode a Data Matrix Code represented as a 2D array of booleans. "true" is taken to mean a black module.
@param image booleans representing white/black Data Matrix Code modules @return text and bytes encoded within the Data Matrix Code @throws FormatException if the Data Matrix Code cannot be decoded @throws ChecksumException if error correction fails