GenericMultipleBarcodeReader

Struct GenericMultipleBarcodeReader 

pub struct GenericMultipleBarcodeReader<T: Reader>(/* private fields */);
Attempts to locate multiple barcodes in an image by repeatedly decoding portion of the image. After one barcode is found, the areas left, above, right and below the barcode's {@link Point}s are scanned, recursively.

A caller may want to also employ {@link ByQuadrantReader} when attempting to find multiple 2D barcodes, like QR Codes, in an image, where the presence of multiple barcodes might prevent detecting any one of them.

That is, instead of passing a {@link Reader} a caller might pass {@code new ByQuadrantReader(reader)}.

@author Sean Owen

Implementations

Source

impl<T: Reader> GenericMultipleBarcodeReader<T>

pub fn new(delegate: T) -> Self