Module rxing::oned

source ·

Modules

Structs

Constants

Statics

Traits

  • Encapsulates functionality and implementation that is common to all families of one-dimensional barcodes.
  • Encapsulates functionality and implementation that is common to one-dimensional barcodes.

  • Encapsulates functionality and implementation that is common to UPC and EAN families

  • Encapsulates functionality and implementation that is common to UPC and EAN families

Functions

  • Expands a UPC-E value back into its full, equivalent UPC-A code value.
  • Determines how closely a set of observed counts of runs of black/white values matches a given target pattern. This is reported as the ratio of the total variance from the expected pattern proportions across all pattern elements, to the length of the pattern.
  • Records the size of successive runs of white and black pixels in a row, starting at a given point. The values are recorded in the given array, and the number of runs recorded is equal to the size of the array. If the row starts on a white pixel at the given start point, then the first count recorded is the run of white pixels starting from that point; likewise it is the count of a run of black pixels if the row begin on a black pixels at that point.