Struct rxing::oned::Code93Reader
source · pub struct Code93Reader { /* private fields */ }Expand description
Decodes Code 93 barcodes.
@author Sean Owen @see Code39Reader
Implementations
sourceimpl Code93Reader
impl Code93Reader
pub const ALPHABET_STRING: &'static str = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ-. $/+%abcd*"
pub const ALPHABET: [char; 48] = _
sourcepub const CHARACTER_ENCODINGS: [u32; 48] = _
pub const CHARACTER_ENCODINGS: [u32; 48] = _
These represent the encodings of characters, as patterns of wide and narrow bars. The 9 least-significant bits of each int correspond to the pattern of wide and narrow.
pub const ASTERISK_ENCODING: i32 = 350i32
pub fn new() -> Self