pub struct BarcodeMatrix { /* private fields */ }Expand description
Holds all of the information for a barcode in a format where it can be easily accessible
@author Jacob Haynes
Implementations
Sourceimpl BarcodeMatrix
impl BarcodeMatrix
Sourcepub fn new(height: usize, width: usize, compact: bool) -> Self
pub fn new(height: usize, width: usize, compact: bool) -> Self
@param height the height of the matrix (Rows) @param width the width of the matrix (Cols) @param compact if true, enables compaction
pub fn set(&mut self, x: usize, y: usize, value: u8)
pub fn startRow(&mut self)
pub fn getCurrentRow(&self) -> &BarcodeRow
pub fn getCurrentRowMut(&mut self) -> &mut BarcodeRow
pub fn getMatrix(&self) -> Vec<Vec<u8>>
pub fn getScaledMatrix(&self, xScale: usize, yScale: usize) -> Vec<Vec<u8>>