pub fn CorrectErrors(
    codewordBytes: &mut [u8],
    numDataCodewords: u32
) -> Result<bool>
Given data and error-correction codewords received, possibly corrupted by errors, attempts to correct the errors in-place using Reed-Solomon error correction.

@param codewordBytes data and error correction codewords @param numDataCodewords number of codewords that are data bytes @return false if error correction fails