pub struct QrReader;Trait Implementations
sourceimpl MultipleBarcodeReader for QrReader
impl MultipleBarcodeReader for QrReader
fn decode_multiple<B: Binarizer>( &mut self, image: &mut BinaryBitmap<B> ) -> Result<Vec<RXingResult>>
fn decode_multiple_with_hints<B: Binarizer>( &mut self, image: &mut BinaryBitmap<B>, hints: &DecodingHintDictionary ) -> Result<Vec<RXingResult>>
sourceimpl Reader for QrReader
impl Reader for QrReader
sourcefn decode<B: Binarizer>(
&mut self,
image: &mut BinaryBitmap<B>
) -> Result<RXingResult>
fn decode<B: Binarizer>( &mut self, image: &mut BinaryBitmap<B> ) -> Result<RXingResult>
Locates and decodes a barcode in some format within an image. Read more
sourcefn decode_with_hints<B: Binarizer>(
&mut self,
image: &mut BinaryBitmap<B>,
hints: &DecodingHintDictionary
) -> Result<RXingResult>
fn decode_with_hints<B: Binarizer>( &mut self, image: &mut BinaryBitmap<B>, hints: &DecodingHintDictionary ) -> Result<RXingResult>
Locates and decodes a barcode in some format within an image. This method also accepts
hints, each possibly associated to some data, which may help the implementation decode. Read more