pub struct AlignmentPattern { /* private fields */ }Expand description
Encapsulates an alignment pattern, which are the smaller square patterns found in all but the simplest QR Codes.
@author Sean Owen
Implementations
Sourceimpl AlignmentPattern
impl AlignmentPattern
pub fn new(posX: f32, posY: f32, estimatedModuleSize: f32) -> Self
Sourcepub fn aboutEquals(&self, moduleSize: f32, i: f32, j: f32) -> bool
pub fn aboutEquals(&self, moduleSize: f32, i: f32, j: f32) -> bool
Determines if this alignment pattern "about equals" an alignment pattern at the stated position and size -- meaning, it is at nearly the same center with nearly the same size.
Sourcepub fn combineEstimate(
&self,
i: f32,
j: f32,
newModuleSize: f32,
) -> AlignmentPattern
pub fn combineEstimate( &self, i: f32, j: f32, newModuleSize: f32, ) -> AlignmentPattern
Combines this object’s current estimate of a finder pattern position and module size with a new estimate. It returns a new {@code FinderPattern} containing an average of the two.