Struct rxing::qrcode::encoder::ByteMatrix
source · pub struct ByteMatrix { /* private fields */ }Expand description
JAVAPORT: The original code was a 2D array of ints, but since it only ever gets assigned -1, 0, and 1, I’m going to use less memory and go with bytes.
@author dswitkin@google.com (Daniel Switkin)
Implementations
sourceimpl ByteMatrix
impl ByteMatrix
pub fn new(width: u32, height: u32) -> Self
pub fn getHeight(&self) -> u32
pub fn getWidth(&self) -> u32
pub fn get(&self, x: u32, y: u32) -> u8
sourcepub fn getArray(&self) -> &Vec<Vec<u8>>
pub fn getArray(&self) -> &Vec<Vec<u8>>
@return an internal representation as bytes, in row-major order. array[y][x] represents point (x,y)
pub fn set(&mut self, x: u32, y: u32, value: u8)
pub fn set_bool(&mut self, x: u32, y: u32, value: bool)
pub fn clear(&mut self, value: u8)