PointCallback

Type Alias PointCallback 

pub type PointCallback = Arc<dyn Fn(Point) + Send + Sync>;
Callback which is invoked when a possible result point (significant point in the barcode image such as a corner) is found.

Aliased Type

pub struct PointCallback { /* private fields */ }