Struct rxing::common::DecoderRXingResult
source · pub struct DecoderRXingResult { /* private fields */ }Expand description
Encapsulates the result of decoding a matrix of bits. This typically applies to 2D barcode formats. For now it contains the raw bytes obtained, as well as a String interpretation of those bytes, if applicable.
@author Sean Owen
Implementations
sourceimpl DecoderRXingResult
impl DecoderRXingResult
pub fn new( rawBytes: Vec<u8>, text: String, byteSegments: Vec<Vec<u8>>, ecLevel: String ) -> Self
pub fn with_symbology( rawBytes: Vec<u8>, text: String, byteSegments: Vec<Vec<u8>>, ecLevel: String, symbologyModifier: u32 ) -> Self
pub fn with_sa( rawBytes: Vec<u8>, text: String, byteSegments: Vec<Vec<u8>>, ecLevel: String, saSequence: i32, saParity: i32 ) -> Self
pub fn with_all( rawBytes: Vec<u8>, text: String, byteSegments: Vec<Vec<u8>>, ecLevel: String, saSequence: i32, saParity: i32, symbologyModifier: u32, contentType: String, isMirrored: bool ) -> Self
sourcepub fn getRawBytes(&self) -> &Vec<u8> ⓘ
pub fn getRawBytes(&self) -> &Vec<u8> ⓘ
@return raw bytes representing the result, or {@code null} if not applicable
sourcepub fn getNumBits(&self) -> usize
pub fn getNumBits(&self) -> usize
@return how many bits of {@link #getRawBytes()} are valid; typically 8 times its length @since 3.3.0
sourcepub fn setNumBits(&mut self, numBits: usize)
pub fn setNumBits(&mut self, numBits: usize)
@param numBits overrides the number of bits that are valid in {@link #getRawBytes()} @since 3.3.0
sourcepub fn getByteSegments(&self) -> &Vec<Vec<u8>>
pub fn getByteSegments(&self) -> &Vec<Vec<u8>>
@return list of byte segments in the result, or {@code null} if not applicable
sourcepub fn getECLevel(&self) -> &str
pub fn getECLevel(&self) -> &str
@return name of error correction level used, or {@code null} if not applicable
sourcepub fn getErrorsCorrected(&self) -> usize
pub fn getErrorsCorrected(&self) -> usize
@return number of errors corrected, or {@code null} if not applicable
pub fn setErrorsCorrected(&mut self, errorsCorrected: usize)
sourcepub fn getErasures(&self) -> usize
pub fn getErasures(&self) -> usize
@return number of erasures corrected, or {@code null} if not applicable
pub fn setErasures(&mut self, erasures: usize)
pub fn setOther(&mut self, other: Option<Rc<dyn Any>>)
pub fn hasStructuredAppend(&self) -> bool
pub fn getStructuredAppendParity(&self) -> i32
pub fn getStructuredAppendSequenceNumber(&self) -> i32
pub fn getSymbologyModifier(&self) -> u32
pub fn getContentType(&self) -> &str
pub fn setContentType(&mut self, content_type: String)
pub fn getIsMirrored(&self) -> bool
pub fn setIsMirrored(&mut self, is_mirrored: bool)