Struct rxing::datamatrix::decoder::Decoder
source · pub struct Decoder(_);Expand description
The main class which implements Data Matrix Code decoding -- as opposed to locating and extracting the Data Matrix Code from an image.
@author bbrown@google.com (Brian Brown)
Implementations
sourceimpl Decoder
impl Decoder
pub fn new() -> Self
sourcepub fn decode_bools(
&self,
image: &Vec<Vec<bool>>
) -> Result<DecoderRXingResult, Exceptions>
pub fn decode_bools(
&self,
image: &Vec<Vec<bool>>
) -> Result<DecoderRXingResult, Exceptions>
Convenience method that can decode a Data Matrix Code represented as a 2D array of booleans. "true" is taken to mean a black module.
@param image booleans representing white/black Data Matrix Code modules @return text and bytes encoded within the Data Matrix Code @throws FormatException if the Data Matrix Code cannot be decoded @throws ChecksumException if error correction fails
sourcepub fn decode(&self, bits: &BitMatrix) -> Result<DecoderRXingResult, Exceptions>
pub fn decode(&self, bits: &BitMatrix) -> Result<DecoderRXingResult, Exceptions>
Decodes a Data Matrix Code represented as a {@link BitMatrix}. A 1 or "true" is taken to mean a black module.
@param bits booleans representing white/black Data Matrix Code modules @return text and bytes encoded within the Data Matrix Code @throws FormatException if the Data Matrix Code cannot be decoded @throws ChecksumException if error correction fails