Modules
Structs
Decodes Codabar barcodes.
- This class renders CodaBar as {@code boolean[]}.
Decodes Code 39 barcodes. Supports "Full ASCII Code 39" if USE_CODE_39_EXTENDED_MODE is set.
- This object renders a CODE39 code as a {@link BitMatrix}.
Decodes Code 93 barcodes.
- This object renders a CODE93 code as a BitMatrix
Decodes Code 128 barcodes.
- This object renders a CODE128 code as a {@link BitMatrix}.
Implements decoding of the EAN-8 format.
- This object renders an EAN8 code as a {@link BitMatrix}.
Implements decoding of the EAN-13 format.
- This object renders an EAN13 code as a {@link BitMatrix}.
- Records EAN prefix to GS1 Member Organization, where the member organization correlates strongly with a country. This is an imperfect means of identifying a country of origin by EAN-13 barcode value. See http://en.wikipedia.org/wiki/List_of_GS1_country_codes.
Implements decoding of the ITF format, or Interleaved Two of Five.
- This object renders a ITF code as a {@link BitMatrix}.
- @author dswitkin@google.com (Daniel Switkin) @author Sean Owen
A reader that can read all available UPC/EAN formats. If a caller wants to try to
Implements decoding of the UPC-A format.
- This object renders a UPC-A code as a {@link BitMatrix}.
- @see UPCEANExtension5Support
- @see UPCEANExtension2Support
Implements decoding of the UPC-E format.
- This object renders an UPC-E code as a {@link BitMatrix}.
Constants
- end guard pattern.
- As above but also including the “even”, or “G” patterns used to encode UPC/EAN digits.
- “Odd”, or “L” patterns used to encode UPC/EAN digits.
- Pattern marking the middle of a UPC/EAN pattern, separating the two halves.
- Start/end guard pattern.
Statics
Traits
- Encapsulates functionality and implementation that is common to all families of one-dimensional barcodes.
Encapsulates functionality and implementation that is common to one-dimensional barcodes.
Encapsulates functionality and implementation that is common to UPC and EAN families
Encapsulates functionality and implementation that is common to UPC and EAN families
Functions
- Expands a UPC-E value back into its full, equivalent UPC-A code value.
- Determines how closely a set of observed counts of runs of black/white values matches a given target pattern. This is reported as the ratio of the total variance from the expected pattern proportions across all pattern elements, to the length of the pattern.
- Records the size of successive runs of white and black pixels in a row, starting at a given point. The values are recorded in the given array, and the number of runs recorded is equal to the size of the array. If the row starts on a white pixel at the given start point, then the first count recorded is the run of white pixels starting from that point; likewise it is the count of a run of black pixels if the row begin on a black pixels at that point.