Struct rxing::oned::Code39Reader
source · pub struct Code39Reader { /* private fields */ }Expand description
Decodes Code 39 barcodes. Supports "Full ASCII Code 39" if USE_CODE_39_EXTENDED_MODE is set.
@author Sean Owen @see Code93Reader
Implementations
sourceimpl Code39Reader
impl Code39Reader
pub const ALPHABET_STRING: &'static str = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ-. $/+%"
sourcepub const CHARACTER_ENCODINGS: [u32; 43] = _
pub const CHARACTER_ENCODINGS: [u32; 43] = _
These represent the encodings of characters, as patterns of wide and narrow bars. The 9 least-significant bits of each int correspond to the pattern of wide and narrow, with 1s representing “wide” and 0s representing narrow.
pub const ASTERISK_ENCODING: u32 = 148u32
sourcepub fn new() -> Self
pub fn new() -> Self
Creates a reader that assumes all encoded data is data, and does not treat the final character as a check digit. It will not decoded “extended Code 39” sequences.
sourcepub fn with_use_check_digit(usingCheckDigit: bool) -> Self
pub fn with_use_check_digit(usingCheckDigit: bool) -> Self
Creates a reader that can be configured to check the last character as a check digit. It will not decoded “extended Code 39” sequences.
@param usingCheckDigit if true, treat the last data character as a check digit, not data, and verify that the checksum passes.
sourcepub fn with_all_config(usingCheckDigit: bool, extendedMode: bool) -> Self
pub fn with_all_config(usingCheckDigit: bool, extendedMode: bool) -> Self
Creates a reader that can be configured to check the last character as a check digit, or optionally attempt to decode “extended Code 39” sequences that are used to encode the full ASCII character set.
@param usingCheckDigit if true, treat the last data character as a check digit, not data, and verify that the checksum passes. @param extendedMode if true, will attempt to decode extended Code 39 sequences in the text.