Modules
Structs
- Barcode
Matrix - Holds all of the information for a barcode in a format where it can be easily accessible
- Barcode
Row - @author Jacob Haynes
- Dimensions
- Data object to specify the minimum and maximum number of rows and columns for a PDF417 barcode.
- PDF417
- Top-level class for the logic part of the PDF417 implementation.
Enums
- Compaction
- Represents possible PDF417 barcode compaction types.