Modules
Structs
- @author Sean Owen
Encapsulates a block of data within a QR Code. QR Codes may split their data into
Encapsulates the parameters for one error-correction block in one symbol version.
Encapsulates a set of error-correction blocks in one symbol version. Most versions will
Encapsulates a QR Code's format information, including the data mask used and
- Meta-data container for QR Code decoding. Instances of this class may be used to convey information back to the decoding caller. Callers are expected to process this.
- See ISO 18004:2006 Annex D
Enums
Encapsulates data masks for the data bits in a QR code, per ISO 18004:2006 6.8. Implementations
See ISO 18004:2006, 6.5.1. This enum encapsulates the four error correction levels
See ISO 18004:2006, 6.4.1, Tables 2 and 3. This enum encapsulates the various modes in which
Constants
- See ISO 18004:2006, Annex C, Table C.1
- See ISO 18004:2006 Annex D. Element i represents the raw version bits that specify version i + 7